@Echo Off

Rem
Rem  NOTE:  The CACLS commands in this script are only effective
Rem         on NTFS formatted partitions.
Rem

Rem #########################################################################

Rem
Rem Verify that %RootDrive% has been configured and set it for this script.
Rem

Call "%SystemRoot%\Application Compatibility Scripts\ChkRoot.Cmd"
If "%_CHKROOT%" == "FAIL" Goto Done

Rem #########################################################################

Rem
Rem Get the installation location of Office 97 from the registry.  If
Rem not found, assume Office isn't installed and display an error message.
Rem

..\ACRegL %Temp%\O97.Cmd O97INST "HKLM\Software\Microsoft\Office\8.0\Common\InstallRoot" "" ""
If Not ErrorLevel 1 Goto Cont0
Echo.
Echo Unable to retrieve Office 97 installation location from the registry.
Echo Verify that Office 97 has already been installed and run this script
Echo again.
Echo.
Pause
Goto Done

:Cont0
Call %Temp%\O97.Cmd
Del %Temp%\O97.Cmd >Nul: 2>&1

Rem #########################################################################

Rem
Rem Change the Access 97 System Database to Read only.  This lets
Rem multiple people run the database simultaneously.  However, it
Rem disables the ability to update the System Database, which is
Rem normally done through the Tools/Security menu option.  If you
Rem need to add users, first you must put write access back on the
Rem system database.
Rem

If Not Exist %SystemRoot%\System32\System.Mdw Goto Cont1
cacls %SystemRoot%\System32\System.Mdw /E /P EveryOne:R >NUL: 2>&1
cacls %SystemRoot%\System32\System.Mdw /E /P Administrators:R >NUL: 2>&1
:Cont1

Rem #########################################################################

Rem
Rem Allow read access for everybody on a system DLL that is updated by
Rem Office 97.
Rem

If Exist %SystemRoot%\System32\OleAut32.Dll cacls %SystemRoot%\System32\OleAut32.Dll /E /T /G EveryOne:R >NUL: 2>&1

Rem #########################################################################

Rem
Rem Change Powerpoint Wizards to Read Only to allow more than one
Rem simultaneous invocation of the Wizard.
Rem

If Exist "%O97INST%\Modelli\Presentazioni\Autocomposizione Contenuto.Pwz" Attrib +R "%O97INST%\Modelli\Presentazioni\Autocomposizione Contenuto.Pwz" >Nul: 2>&1
If Exist "%O97INST%\Office\Ppt2html.ppa" Attrib +R "%O97INST%\Office\Ppt2html.ppa" >Nul: 2>&1
If Exist "%O97INST%\Office\bshppt97.ppa" Attrib +R "%O97INST%\Office\bshppt97.ppa" >Nul: 2>&1
If Exist "%O97INST%\Office\geniwiz.ppa" Attrib +R "%O97INST%\Office\geniwiz.ppa" >Nul: 2>&1
If Exist "%O97INST%\Office\ppttools.ppa" Attrib +R "%O97INST%\Office\ppttools.ppa" >Nul: 2>&1

Rem #########################################################################

Rem
Rem Create the MsForms.Twd and RefEdit.Twd files, which are needed for 
Rem Powerpoint and Excel Add-ins (File/Save as HTML, etc).  When either 
Rem program is run, they will replace the appropriate file with one 
Rem containing the necessary data.
Rem

If Exist %systemroot%\system32\MsForms.Twd Goto Cont2
Copy Nul: %systemroot%\system32\MsForms.Twd >Nul: 2>&1
Cacls %systemroot%\system32\MsForms.Twd /E /P EveryOne:F >Nul: 2>&1
:Cont2

If Exist %systemroot%\system32\RefEdit.Twd Goto Cont3
Copy Nul: %systemroot%\system32\RefEdit.Twd >Nul: 2>&1
Cacls %systemroot%\system32\RefEdit.Twd /E /P EveryOne:F >Nul: 2>&1
:Cont3

Rem #########################################################################

Rem
Rem Remove Find Fast from the Startup menu for all users.
Rem Find Fast is resource intensive and will impact system
Rem performance.
Rem

If Exist "%SystemRoot%\Profiles\All Users\Start Menu\Programs\Startup\Ricerca Rapida.lnk" Del "%SystemRoot%\Profiles\All Users\Start Menu\Programs\Startup\Ricerca Rapida.lnk" >Nul: 2>&1
If Exist "%SystemRoot%\Profiles\All Users\Start Menu\Programs\Startup\Avvio Office.lnk" Del "%SystemRoot%\Profiles\All Users\Start Menu\Programs\Startup\Avvio Office.lnk" >Nul: 2>&1
If Exist "%SystemRoot%\Profiles\All Users\Start Menu\Programs\Startup\Barra Degli Strumenti Microsoft Office.lnk" Del "%SystemRoot%\Profiles\All Users\Start Menu\Programs\Startup\Barra Degli Strumenti Microsoft Office.lnk" >Nul: 2>&1

Rem #########################################################################

Rem
Rem Change Registry Keys to make paths point to user specific
Rem directories.
Rem

Rem If not currently in Install Mode, change to Install Mode.
Set __OrigMode=Install
ChgUsr /query > Nul:
if Not ErrorLevel 101 Goto Begin
Set __OrigMode=Exec
Change User /Install > Nul:
:Begin

..\acsr "#ROOTDRIVE#" "%RootDrive%" Template\Office97ita.Key Office97.Tmp
..\acsr "#INSTDIR#" "%O97INST%" Office97.Tmp Office97.Key
Del Office97.Tmp >Nul: 2>&1

regini Office97.key > Nul:

Rem If original mode was execute, change back to Execute Mode.
If "%__OrigMode%" == "Exec" Change User /Execute > Nul:
Set __OrigMode=

Rem #########################################################################

Rem
Rem Update Ofc97Usr.Cmd to reflect actual installation directory and
Rem add it to the UsrLogn2.Cmd script
Rem

..\acsr "#INSTDIR#" "%O97INST%" ..\Logon\Template\Ofc97IUsr.Cmd ..\Logon\Ofc97Usr.Cmd

FindStr /I Ofc97Usr %SystemRoot%\System32\UsrLogn2.Cmd >Nul: 2>&1
If Not ErrorLevel 1 Goto Skip1
Echo Call Ofc97Usr.Cmd >> %SystemRoot%\System32\UsrLogn2.Cmd
:Skip1

Echo.
Echo   To insure proper operation of Office 97, users who are
Echo   currently logged on must log off and log on again before
Echo   running any Office 97 application.
Echo.
Echo Microsoft Office 97 Multi-user Application Tuning Complete
Pause

:done
